==> nextcloud-18.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files/l10n/cs.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Úložiště je dočasně nedostupné",
    "Storage invalid" : "Neplatné úložiště",
    "Unknown error" : "Neznámá chyba",
    "All files" : "Všechny soubory",
    "Recent" : "Nedávné",
    "Favorites" : "Oblíbené",
    "File could not be found" : "Soubor se nedaří nalézt",
    "Move or copy" : "Přesunout nebo zkopírovat",
    "Download" : "Stáhnout",
    "Delete" : "Smazat",
    "Home" : "Domů",
    "Close" : "Zavřít",
    "Could not create folder \"{dir}\"" : "Složku „{dir}“ nelze vytvořit",
    "This will stop your current uploads." : "Toto zastaví stávající nahrávání.",
    "Upload cancelled." : "Nahrávání zrušeno.",
    "Processing files …" : "Zpracovávání souborů…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Soubor {filename} nelze nahrát, protože je to buď adresář nebo má velikost nula bajtů",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nedostatek místa pro uložení – velikost souboru je {size1}, ale zbývá pouze {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Cílová složka „{dir}“ už neexistuje",
    "Not enough free space" : "Nedostatek volného prostoru",
    "An unknown error has occurred" : "Vyskytla se neznámá chyba",
    "Uploading …" : "Nahrávání…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Nahrání této položky není podporováno",
    "Target folder does not exist any more" : "Cílová složka už neexistuje",
    "Error when assembling chunks, status code {status}" : "Chyba při kompletaci shluků, kód chyby {status}",
    "Actions" : "Akce",
    "Rename" : "Přejmenovat",
    "Copy" : "Kopírovat",
    "Choose target folder" : "Zvolte cílovou složku",
    "Open" : "Otevřít",
    "Delete file" : "Smazat soubor",
    "Delete folder" : "Smazat složku",
    "Disconnect storage" : "Odpojit úložiště",
    "Unshare" : "Zrušit sdílení",
    "Could not load info for file \"{file}\"" : "Nepodařilo se načíst informace pro soubor „{file}“",
    "Files" : "Soubory",
    "Details" : "Podrobnosti",
    "Select" : "Vybrat",
    "Pending" : "Nevyřízené",
    "Unable to determine date" : "Nelze určit datum",
    "This operation is forbidden" : "Tato operace je zakázána",
    "This directory is unavailable, please check the logs or contact the administrator" : "Tento adresář není dostupný, zkontrolujte záznamy událostí nebo se obraťte na správce",
    "Could not move \"{file}\", target exists" : "„{file}“ nelze přesunout – cíl už existuje",
    "Could not move \"{file}\"" : "„{file}“ nelze přesunout",
    "copy" : "kopie",
    "Could not copy \"{file}\", target exists" : "Nelze kopírovat „{file}“, cíl už existuje",
    "Could not copy \"{file}\"" : "Nelze kopírovat „{file}“",
    "Copied {origin} inside {destination}" : "{origin} zkopírován do {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} a {nbfiles} dalších souborů zkopírováno do {destination}",
    "{newName} already exists" : "{newName} už existuje",
    "Could not rename \"{fileName}\", it does not exist any more" : "„{fileName}“ nelze přejmenovat – už neexistuje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Název „{targetName}“ je už použitý ve složce „{dir}“. Zvolte jiný název.",
    "Could not rename \"{fileName}\"" : "„{fileName}“ nelze přejmenovat",
    "Could not create file \"{file}\"" : "Soubor „{file}“ nelze vytvořit",
    "Could not create file \"{file}\" because it already exists" : "Soubor „{file}“ nelze vytvořit, protože zde už existuje",
    "Could not create folder \"{dir}\" because it already exists" : "Složku „{dir}“ nelze vytvořit, protože už existuje",
    "Error deleting file \"{fileName}\"." : "Chyba mazání souboru „{fileName}“.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Žádné výsledky hledání v ostatních složkách pro {tag}{filter}{endtag}",
    "Name" : "Název",
    "Size" : "Velikost",
    "Modified" : "Změněno",
    "_%n folder_::_%n folders_" : ["%n složka","%n složky","%n složek","%n složky"],
    "_%n file_::_%n files_" : ["%n soubor","%n soubory","%n souborů","%n soubory"],
    "{dirs} and {files}" : "{dirs} a {files}",
    "_including %n hidden_::_including %n hidden_" : ["včetně %n skrytého","včetně %n skrytých","včetně %n skrytých","včetně %n skrytých"],
    "You don’t have permission to upload or create files here" : "Nemáte oprávnění sem nahrávat nebo vytvářet soubory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahrává se %n soubor","Nahrávají se %n soubory","Nahrává se %n souborů","Nahrávají se %n soubory"],
    "New" : "Nový",
    "Select file range" : "Vybrat rozsah souborů",
    "{used} of {quota} used" : "Využito {used} z {quota} ",
    "{used} used" : "{used} využito",
    "\"{name}\" is an invalid file name." : "„{name}“ není platným názvem souboru.",
    "File name cannot be empty." : "Je třeba vyplnit název souboru.",
    "\"/\" is not allowed inside a file name." : "„/“ není povolený znak v názvu souboru.",
    "\"{name}\" is not an allowed filetype" : "„{name}“ není povolený typ souboru",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Úložiště uživatele {owner} je zaplněné – nelze aktualizovat ani synchronizovat soubory!",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložiště je plné – nelze aktualizovat ani synchronizovat soubory!.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Úložiště uživatele {owner} je téměř plné ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše úložiště je téměř plné ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["odpovídá „{filter}“","odpovídají „{filter}“","odpovídá „{filter}“","odpovídají „{filter}“"],
    "View in folder" : "Zobrazit ve složce",
    "Copied!" : "Zkopírováno!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Zkopírovat přímý odkaz (funguje pouze pro uživatele, kteří mají přístup k tomuto souboru/složce)",
    "Path" : "Popis umístění",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtů","%n bajty"],
    "Favorited" : "Přidáno mezi oblíbené",
    "Favorite" : "Oblíbené",
    "You can only favorite a single file or folder at a time" : "Do oblíbených lze soubory a složky zařazovat jen jednotlivě",
    "New folder" : "Nová složka",
    "Upload file" : "Nahrát soubor",
    "Not favorited" : "Nepřidáno do oblíbených",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Add to favorites" : "Přidat do oblíbených",
    "An error occurred while trying to update the tags" : "Při pokusu o úpravu štítků došlo k chybě",
    "Added to favorites" : "Přidáno do oblíbených",
    "Removed from favorites" : "Odebráno z oblíbených",
    "You added {file} to your favorites" : "Do svých oblíbených jste přidali {file}",
    "You removed {file} from your favorites" : "Odstranili jste {file} ze svých oblíbených",
    "File changes" : "Změny souboru",
    "Created by {user}" : "Vytvořil(a) {user}",
    "Changed by {user}" : "Změnil(a) {user}",
    "Deleted by {user}" : "Odstranil(a) {user}",
    "Restored by {user}" : "Obnovil(a) {user}",
    "Renamed by {user}" : "Přejmenoval(a) {user}",
    "Moved by {user}" : "Přesunul(a) {user}",
    "\"remote user\"" : "„uživatel na protějšku“",
    "You created {file}" : "Vytvořili jste {file}",
    "You created an encrypted file in {file}" : "Vytvořili jste šifrovaný soubor v {file}",
    "{user} created {file}" : "{user} vytvořil(a) {file}",
    "{user} created an encrypted file in {file}" : "{user} vytvořil(a) šifrovaný soubor v {file}",
    "{file} was created in a public folder" : "Soubor {file} byl vytvořen ve veřejné složce",
    "You changed {file}" : "Změnili jste {file}",
    "You changed an encrypted file in {file}" : "Změnili jste šifrovaný soubor v {file}",
    "{user} changed {file}" : "{user} změnil(a) {file}",
    "{user} changed an encrypted file in {file}" : "{user} změnil(a) šifrovaný soubor v {file}",
    "You deleted {file}" : "Odstranili jste {file}",
    "You deleted an encrypted file in {file}" : "Smazali jste šifrovaný soubor v {file}",
    "{user} deleted {file}" : "{user} smazal(a) {file}",
    "{user} deleted an encrypted file in {file}" : "{user} smazal(a) šifrovaný soubor v {file}",
    "You restored {file}" : "Obnovili jste {file}",
    "{user} restored {file}" : "{user} obnovil(a) {file}",
    "You renamed {oldfile} to {newfile}" : "Přejmenovali jste {oldfile} na {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} přejmenoval(a) {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "{oldfile} jste přesunuli do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} přesunul(a) {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Soubor byl přidán, nebo odstraněn z vašich <strong>oblíbených</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Soubor nebo složka byla <strong>změněna</strong> nebo <strong>přejmenována</strong>",
    "A new file or folder has been <strong>created</strong>" : "Byl <strong>vytvořen</strong> nový soubor nebo složka",
    "A file or folder has been <strong>deleted</strong>" : "Soubor nebo složka byla <strong>smazána</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Upozorňovat na vytváření a změny pouze u vašich <strong>oblíbených souborů</strong> <em>(pouze v Proud)</em>",
    "A file or folder has been <strong>restored</strong>" : "Soubor nebo složka byla <strong>obnovena</strong>",
    "Unlimited" : "Neomezeně",
    "Upload (max. %s)" : "Nahrát (max. %s)",
    "Accept" : "Přijmout",
    "Reject" : "Odmítnout",
    "Incoming ownership transfer from {user}" : "Příchozí převedení vlastnictví od {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Chcete přijmout {path}?\n\nPozn.: Proces po přijetí může trvat až hodinu.",
    "Ownership transfer failed" : "Převedení vlastnictví se nezdařilo",
    "Your ownership transfer of {path} to {user} failed." : "Převedení vlastnictví {path} od vás na {user} se nezdařilo.",
    "The ownership transfer of {path} from {user} failed." : "Převedení vlastnictví {path} od {user} se nezdařilo.",
    "Ownership transfer done" : "Převedení vlastnictví dokončeno",
    "Your ownership transfer of {path} to {user} has completed." : "Převedení vámi vlastněného {path} na {user} dokončeno.",
    "The ownership transfer of {path} from {user} has completed." : "Převedení vlastnictví {path} od {user} dokončeno.",
    "File Management" : "Správa souboru",
    "Transfer ownership of a file or folder" : "Převést vlastnictví souboru či složky",
    "Choose file or folder to transfer" : "Zvolte soubor nebo složku k převedení",
    "Change" : "Změnit",
    "New owner" : "Nový vlastník",
    "Search users" : "Hledat uživatele",
    "Choose a file or folder to transfer" : "Zvolte soubor nebo složku k převedení",
    "Transfer" : "Převedení",
    "Transfer {path} to {userid}" : "Převést {path} na {userid}",
    "Invalid path selected" : "Vybrán neplatný popis umístění",
    "Ownership transfer request sent" : "Žádost o převedení vlastnictví zaslána",
    "Tags" : "Značky",
    "Error while loading the file data" : "Chyba při načítání dat souboru",
    "Unable to change the favourite state of the file" : "Nedaří se změnit stav „oblíbené“ souboru",
    "%s used" : "%s použito",
    "%s%% of %s used" : "%s%% z %s použito",
    "%1$s of %2$s used" : "%1$s z %2$s použito",
    "Settings" : "Nastavení",
    "Show hidden files" : "Zobrazit skryté soubory",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Použijte tuto adresu pro <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">přístup k vašim souborům přes WebDAV</a>",
    "Toggle grid view" : "Vyp/zap. zobrazení v mřížce",
    "No files in here" : "Žádné soubory",
    "Upload some content or sync with your devices!" : "Nahrajte nějaký obsah nebo synchronizujte se svými přístroji!",
    "No entries found in this folder" : "V této složce nebylo nic nalezeno",
    "Select all" : "Vybrat vše",
    "Upload too large" : "Nahrávaná data jsou příliš objemná",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Soubory, které se snažíte nahrát, překračují limit velikosti nahrávání na tomto serveru.",
    "No favorites yet" : "Zatím nic oblíbeného",
    "Files and folders you mark as favorite will show up here" : "Zde budou zobrazeny soubory a složky, které označíte jako oblíbené",
    "Deleted files" : "Odstraněné soubory",
    "Shares" : "Sdílení",
    "Shared with others" : "Sdíleno s ostatními",
    "Shared with you" : "Sdíleno s vámi",
    "Shared by link" : "Sdíleno pomocí odkazu",
    "Deleted shares" : "Smazaná sdílení",
    "Pending shares" : "Čekající sdílení",
    "Text file" : "Textový soubor",
    "New text file.txt" : "Nový textový soubor.txt",
    "%s of %s used" : "%s z %s použito",
    "%1$s%% of %2$s used" : "použito %1$s%% z %2$s"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-20.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files/l10n/cs.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Úložiště je dočasně nedostupné",
    "Storage invalid" : "Neplatné úložiště",
    "Unknown error" : "Neznámá chyba",
    "File could not be found" : "Soubor se nedaří nalézt",
    "Move or copy" : "Přesunout nebo zkopírovat",
    "Download" : "Stáhnout",
    "Delete" : "Smazat",
    "Home" : "Domů",
    "Close" : "Zavřít",
    "Favorites" : "Oblíbené",
    "Could not create folder \"{dir}\"" : "Složku „{dir}“ nelze vytvořit",
    "This will stop your current uploads." : "Toto zastaví stávající nahrávání.",
    "Upload cancelled." : "Nahrávání zrušeno.",
    "Processing files …" : "Zpracovávání souborů…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Soubor {filename} nelze nahrát, protože je to buď adresář nebo má velikost nula bajtů",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nedostatek místa pro uložení – velikost souboru je {size1}, ale zbývá pouze {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Cílová složka „{dir}“ už neexistuje",
    "Not enough free space" : "Nedostatek volného prostoru",
    "An unknown error has occurred" : "Vyskytla se neznámá chyba",
    "Uploading …" : "Nahrávání…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Nahrání této položky není podporováno",
    "Target folder does not exist any more" : "Cílová složka už neexistuje",
    "Operation is blocked by access control" : "Operace je blokována řízením přístupu",
    "Error when assembling chunks, status code {status}" : "Chyba při kompletaci shluků, kód chyby {status}",
    "Actions" : "Akce",
    "Rename" : "Přejmenovat",
    "Copy" : "Kopírovat",
    "Choose target folder" : "Zvolte cílovou složku",
    "Open" : "Otevřít",
    "Delete file" : "Smazat soubor",
    "Delete folder" : "Smazat složku",
    "Disconnect storage" : "Odpojit úložiště",
    "Leave this share" : "Opustit toto sdílení",
    "Could not load info for file \"{file}\"" : "Nepodařilo se načíst informace pro soubor „{file}“",
    "Files" : "Soubory",
    "Details" : "Podrobnosti",
    "Select" : "Vybrat",
    "Pending" : "Nevyřízené",
    "Unable to determine date" : "Nelze určit datum",
    "This operation is forbidden" : "Tato operace je zakázána",
    "This directory is unavailable, please check the logs or contact the administrator" : "Tento adresář není dostupný, zkontrolujte záznamy událostí nebo se obraťte na správce",
    "Could not move \"{file}\", target exists" : "„{file}“ nelze přesunout – cíl už existuje",
    "Could not move \"{file}\"" : "„{file}“ nelze přesunout",
    "copy" : "kopie",
    "Could not copy \"{file}\", target exists" : "Nelze kopírovat „{file}“, cíl už existuje",
    "Could not copy \"{file}\"" : "Nelze kopírovat „{file}“",
    "Copied {origin} inside {destination}" : "{origin} zkopírován do {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} a {nbfiles} dalších souborů zkopírováno do {destination}",
    "{newName} already exists" : "{newName} už existuje",
    "Could not rename \"{fileName}\", it does not exist any more" : "„{fileName}“ nelze přejmenovat – už neexistuje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Název „{targetName}“ je už použitý ve složce „{dir}“. Zvolte jiný název.",
    "Could not rename \"{fileName}\"" : "„{fileName}“ nelze přejmenovat",
    "Could not create file \"{file}\"" : "Soubor „{file}“ nelze vytvořit",
    "Could not create file \"{file}\" because it already exists" : "Soubor „{file}“ nelze vytvořit, protože zde už existuje",
    "Could not create folder \"{dir}\" because it already exists" : "Složku „{dir}“ nelze vytvořit, protože už existuje",
    "Could not fetch file details \"{file}\"" : "Nedaří se získat podrobnosti o souboru „{file}“",
    "Error deleting file \"{fileName}\"." : "Chyba mazání souboru „{fileName}“.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Žádné výsledky hledání v ostatních složkách pro {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Pokud chcete hledat v ostatních složkách, zadejte více než dva znaky",
    "Name" : "Název",
    "Size" : "Velikost",
    "Modified" : "Změněno",
    "_%n folder_::_%n folders_" : ["%n složka","%n složky","%n složek","%n složky"],
    "_%n file_::_%n files_" : ["%n soubor","%n soubory","%n souborů","%n soubory"],
    "{dirs} and {files}" : "{dirs} a {files}",
    "_including %n hidden_::_including %n hidden_" : ["včetně %n skrytého","včetně %n skrytých","včetně %n skrytých","včetně %n skrytých"],
    "You don’t have permission to upload or create files here" : "Nemáte oprávnění sem nahrávat nebo vytvářet soubory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahrává se %n soubor","Nahrávají se %n soubory","Nahrává se %n souborů","Nahrávají se %n soubory"],
    "New" : "Nový",
    "Select file range" : "Vybrat rozsah souborů",
    "{used} of {quota} used" : "Využito {used} z {quota} ",
    "{used} used" : "{used} využito",
    "\"{name}\" is an invalid file name." : "„{name}“ není platným názvem souboru.",
    "File name cannot be empty." : "Je třeba vyplnit název souboru.",
    "\"/\" is not allowed inside a file name." : "„/“ není povolený znak v názvu souboru.",
    "\"{name}\" is not an allowed filetype" : "„{name}“ není povolený typ souboru",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Úložiště uživatele {owner} je zaplněné – nelze aktualizovat ani synchronizovat soubory!",
    "Group folder \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "Skupinová složka „{mountPoint}“ je plná, soubory už nadále není možné aktualizovat nebo synchronizovat!",
    "External storage \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "Externí úložiště „{mountPoint}“ je plné, soubory už nadále není možné aktualizovat nebo synchronizovat!",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložiště je plné – nelze aktualizovat ani synchronizovat soubory!.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Úložiště {owner} je téměř plné ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Skupinová složka „{mountPoint}“ je téměř plná ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externí úložiště „{mountPoint}“ je téměř plné ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Vaše úložiště je téměř plné ({usedSpacePercent}%).",
    "_matches '{filter}'_::_match '{filter}'_" : ["odpovídá „{filter}“","odpovídají „{filter}“","odpovídá „{filter}“","odpovídají „{filter}“"],
    "View in folder" : "Zobrazit ve složce",
    "Copied!" : "Zkopírováno!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Zkopírovat přímý odkaz (funguje pouze pro uživatele, kteří mají přístup k tomuto souboru/složce)",
    "Path" : "Popis umístění",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtů","%n bajty"],
    "Favorited" : "Přidáno mezi oblíbené",
    "Favorite" : "Oblíbené",
    "You can only favorite a single file or folder at a time" : "Do oblíbených lze soubory a složky zařazovat jen jednotlivě",
    "New folder" : "Nová složka",
    "Upload file" : "Nahrát soubor",
    "Recent" : "Nedávné",
    "Not favorited" : "Nepřidáno do oblíbených",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Add to favorites" : "Přidat do oblíbených",
    "An error occurred while trying to update the tags" : "Při pokusu o úpravu štítků došlo k chybě",
    "Added to favorites" : "Přidáno do oblíbených",
    "Removed from favorites" : "Odebráno z oblíbených",
    "You added {file} to your favorites" : "Do svých oblíbených jste přidali {file}",
    "You removed {file} from your favorites" : "Odstranili jste {file} ze svých oblíbených",
    "File changes" : "Změny souboru",
    "Created by {user}" : "Vytvořil(a) {user}",
    "Changed by {user}" : "Změnil(a) {user}",
    "Deleted by {user}" : "Odstranil(a) {user}",
    "Restored by {user}" : "Obnovil(a) {user}",
    "Renamed by {user}" : "Přejmenoval(a) {user}",
    "Moved by {user}" : "Přesunul(a) {user}",
    "\"remote user\"" : "„uživatel na protějšku“",
    "You created {file}" : "Vytvořili jste {file}",
    "You created an encrypted file in {file}" : "Vytvořili jste šifrovaný soubor v {file}",
    "{user} created {file}" : "{user} vytvořil(a) {file}",
    "{user} created an encrypted file in {file}" : "{user} vytvořil(a) šifrovaný soubor v {file}",
    "{file} was created in a public folder" : "Soubor {file} byl vytvořen ve veřejné složce",
    "You changed {file}" : "Změnili jste {file}",
    "You changed an encrypted file in {file}" : "Změnili jste šifrovaný soubor v {file}",
    "{user} changed {file}" : "{user} změnil(a) {file}",
    "{user} changed an encrypted file in {file}" : "{user} změnil(a) šifrovaný soubor v {file}",
    "You deleted {file}" : "Odstranili jste {file}",
    "You deleted an encrypted file in {file}" : "Smazali jste šifrovaný soubor v {file}",
    "{user} deleted {file}" : "{user} smazal(a) {file}",
    "{user} deleted an encrypted file in {file}" : "{user} smazal(a) šifrovaný soubor v {file}",
    "You restored {file}" : "Obnovili jste {file}",
    "{user} restored {file}" : "{user} obnovil(a) {file}",
    "You renamed {oldfile} to {newfile}" : "Přejmenovali jste {oldfile} na {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} přejmenoval(a) {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "{oldfile} jste přesunuli do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} přesunul(a) {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Soubor byl přidán, nebo odstraněn z vašich <strong>oblíbených</strong>",
    "A file or folder has been <strong>changed</strong>" : "Soubor nebo adresář byl <strong>změněn</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Oblíbený soubor nebo složka byla <strong>změněna</strong>",
    "All files" : "Všechny soubory",
    "Unlimited" : "Neomezeně",
    "Upload (max. %s)" : "Nahrát (max. %s)",
    "Accept" : "Přijmout",
    "Reject" : "Odmítnout",
    "Incoming ownership transfer from {user}" : "Příchozí převedení vlastnictví od {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Chcete přijmout {path}?\n\nPozn.: Proces po přijetí může trvat až hodinu.",
    "Ownership transfer failed" : "Převedení vlastnictví se nezdařilo",
    "Your ownership transfer of {path} to {user} failed." : "Převedení vlastnictví {path} od vás na {user} se nezdařilo.",
    "The ownership transfer of {path} from {user} failed." : "Převedení vlastnictví {path} od {user} se nezdařilo.",
    "Ownership transfer done" : "Převedení vlastnictví dokončeno",
    "Your ownership transfer of {path} to {user} has completed." : "Převedení vámi vlastněného {path} na {user} dokončeno.",
    "The ownership transfer of {path} from {user} has completed." : "Převedení vlastnictví {path} od {user} dokončeno.",
    "in %s" : "v %s",
    "File Management" : "Správa souboru",
    "Transfer ownership of a file or folder" : "Převést vlastnictví souboru či složky",
    "Choose file or folder to transfer" : "Zvolte soubor nebo složku k převedení",
    "Change" : "Změnit",
    "New owner" : "Nový vlastník",
    "Search users" : "Hledat uživatele",
    "Choose a file or folder to transfer" : "Zvolte soubor nebo složku k převedení",
    "Transfer" : "Převedení",
    "Transfer {path} to {userid}" : "Převést {path} na {userid}",
    "Invalid path selected" : "Vybrán neplatný popis umístění",
    "Ownership transfer request sent" : "Žádost o převedení vlastnictví zaslána",
    "Cannot transfer ownership of a file or folder you don't own" : "Není možné převést vlastnictví souboru či složky, které nejste vlastníky",
    "Tags" : "Značky",
    "Unable to change the favourite state of the file" : "Nedaří se změnit stav „oblíbené“ souboru",
    "Error while loading the file data" : "Chyba při načítání dat souboru",
    "%s used" : "%s použito",
    "%s%% of %s used" : "%s%% z %s použito",
    "%1$s of %2$s used" : "%1$s z %2$s použito",
    "Settings" : "Nastavení",
    "Show hidden files" : "Zobrazit skryté soubory",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Tuto adresu použijte pro přístup k vašim souborům prostřednictvím protokolu WebDAV",
    "Toggle grid view" : "Vyp/zap. zobrazení v mřížce",
    "No files in here" : "Žádné soubory",
    "Upload some content or sync with your devices!" : "Nahrajte nějaký obsah nebo synchronizujte se svými přístroji!",
    "No entries found in this folder" : "V této složce nebylo nic nalezeno",
    "Select all" : "Vybrat vše",
    "Upload too large" : "Nahrávaná data jsou příliš objemná",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Soubory, které se snažíte nahrát, překračují limit velikosti nahrávání na tomto serveru.",
    "No favorites yet" : "Zatím nic oblíbeného",
    "Files and folders you mark as favorite will show up here" : "Zde budou zobrazeny soubory a složky, které označíte jako oblíbené",
    "Deleted files" : "Odstraněné soubory",
    "Shares" : "Sdílení",
    "Shared with others" : "Sdíleno s ostatními",
    "Shared with you" : "Sdíleno s vámi",
    "Shared by link" : "Sdíleno pomocí odkazu",
    "Deleted shares" : "Smazaná sdílení",
    "Pending shares" : "Čekající sdílení",
    "Text file" : "Textový soubor",
    "New text file.txt" : "Nový textový soubor.txt",
    "Unshare" : "Zrušit sdílení",
    "This group folder is full, files can not be updated or synced anymore!" : "Toto skupinová složka je plná, soubory už nadále už není aktualizovat nebo synchronizovat!",
    "This external storage is full, files can not be updated or synced anymore!" : "Toto externí úložiště je plné, soubory už nadále už není aktualizovat nebo synchronizovat!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Úložiště uživatele {owner} je téměř plné ({usedSpacePercent}%)",
    "This group folder is almost full ({usedSpacePercent}%)" : "Tato skupinová složka je téměř plná ({usedSpacePercent}%)",
    "This external storage is almost full ({usedSpacePercent}%)" : "Toto externí úložiště je téměř plné ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše úložiště je téměř plné ({usedSpacePercent}%)",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Soubor nebo složka byla <strong>změněna</strong> nebo <strong>přejmenována</strong>",
    "A new file or folder has been <strong>created</strong>" : "Byl <strong>vytvořen</strong> nový soubor nebo složka",
    "A file or folder has been <strong>deleted</strong>" : "Soubor nebo složka byla <strong>smazána</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Upozorňovat na vytváření a změny pouze u vašich <strong>oblíbených souborů</strong> <em>(pouze v Proud)</em>",
    "A file or folder has been <strong>restored</strong>" : "Soubor nebo složka byla <strong>obnovena</strong>",
    "Cannot transfter ownership of a file or folder you don't own" : "Není možné převést vlastnictví souboru nebo složky, která vám nenáleží",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Použijte tuto adresu pro <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">přístup k vašim souborům přes WebDAV</a>"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
